@@ -6,7 +6,7 @@ use strict qw(vars refs subs);
 use Meta::Baseline::Lang qw();
 
 our($VERSION,@ISA);
-$VERSION="0.10";
+$VERSION="0.11";
 @ISA=qw(Meta::Baseline::Lang);
 
 #sub my_file($$);
@@ -19,6 +19,9 @@ sub my_file($$) {
 	if($file=~/^manx\/.*\.man$/) {
 		return(1);
 	}
+	if($file=~/^manx\/.*\.\d$/) {
+		return(1);
+	}
 	return(0);
 }
 
@@ -60,7 +63,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 
 	MANIFEST: Manx.pm
 	PROJECT: meta
-	VERSION: 0.10
+	VERSION: 0.11
 
 =head1 SYNOPSIS
 
@@ -122,6 +125,7 @@ None.
 	0.08 MV website construction
 	0.09 MV web site automation
 	0.10 MV SEE ALSO section fix
+	0.11 MV teachers project
 
 =head1 SEE ALSO
 
