@@ -12,18 +12,18 @@ use Meta::Db::Info qw();
 my($def_file,$connections_file,$name,$con_name);
 my($opts)=Meta::Utils::Opts::Opts->new();
 $opts->set_standard();
-$opts->def_devf("def_file","what def XML file to use ?","xmlx/def/movie.xml",\$def_file);
-$opts->def_devf("connections_file","what connections XML file to use ?","xmlx/connections/connections.xml",\$connections_file);
+$opts->def_modu("def_file","what def XML file to use ?","xmlx/def/movie.xml",\$def_file);
+$opts->def_modu("connections_file","what connections XML file to use ?","xmlx/connections/connections.xml",\$connections_file);
 $opts->def_stri("name","what database name ?",undef,\$name);
 $opts->def_stri("con_name","what connection name ?",undef,\$con_name);
 $opts->set_free_allo(0);
 $opts->analyze(\@ARGV);
 
-my($def)=Meta::Db::Def->new_deve($def_file);
+my($def)=Meta::Db::Def->new_modu($def_file);
 if(!defined($name)) {
 	$name=$def->get_name();
 }
-my($connections)=Meta::Db::Connections->new_deve($connections_file);
+my($connections)=Meta::Db::Connections->new_modu($connections_file);
 my($connection)=$connections->get_con_null($con_name);
 
 my($dbi)=Meta::Db::Dbi->new();
@@ -72,7 +72,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 
 	MANIFEST: db_clean.pl
 	PROJECT: meta
-	VERSION: 0.15
+	VERSION: 0.16
 
 =head1 SYNOPSIS
 
@@ -125,11 +125,11 @@ show description and exit
 
 show history and exit
 
-=item B<def_file> (type: devf, default: xmlx/def/movie.xml)
+=item B<def_file> (type: modu, default: xmlx/def/movie.xml)
 
 what def XML file to use ?
 
-=item B<connections_file> (type: devf, default: xmlx/connections/connections.xml)
+=item B<connections_file> (type: modu, default: xmlx/connections/connections.xml)
 
 what connections XML file to use ?
 
@@ -174,6 +174,7 @@ None.
 	0.13 MV SEE ALSO section fix
 	0.14 MV move tests to modules
 	0.15 MV download scripts
+	0.16 MV teachers project
 
 =head1 SEE ALSO
 
