@@ -11,19 +11,19 @@ use Meta::Xml::Parsers::Dbdata qw();
 my($def_file,$connections_file,$name,$con_name,$data_file);
 my($opts)=Meta::Utils::Opts::Opts->new();
 $opts->set_standard();
-$opts->def_devf("def_file","which definition file to use ?","xmlx/def/people.xml",\$def_file);
-$opts->def_devf("connections_file","which connections file to use ?","xmlx/connections/connections.xml",\$connections_file);
+$opts->def_modu("def_file","which definition file to use ?","xmlx/def/people.xml",\$def_file);
+$opts->def_modu("connections_file","which connections file to use ?","xmlx/connections/connections.xml",\$connections_file);
 $opts->def_stri("name","which database name to use ?",undef,\$name);
 $opts->def_stri("con_name","which connection name to use ?",undef,\$con_name);
 $opts->def_devf("data_file","which data file to use ?","xmlx/dbdata/small.xml",\$data_file);
 $opts->set_free_allo(0);
 $opts->analyze(\@ARGV);
 
-#my($def)=Meta::Db::Def->new_deve($def_file);
+#my($def)=Meta::Db::Def->new_modu($def_file);
 #if(!defined($name)) {
 #	$name=$def->get_name();
 #}
-#my($connections)=Meta::Db::Connections->new_deve($connections_file);
+#my($connections)=Meta::Db::Connections->new_modu($connections_file);
 #my($connection);
 #if(defined($con_name)) {
 #	$connection=$connections->get($con_name);
@@ -69,7 +69,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 
 	MANIFEST: db_import.pl
 	PROJECT: meta
-	VERSION: 0.17
+	VERSION: 0.18
 
 =head1 SYNOPSIS
 
@@ -123,11 +123,11 @@ show description and exit
 
 show history and exit
 
-=item B<def_file> (type: devf, default: xmlx/def/people.xml)
+=item B<def_file> (type: modu, default: xmlx/def/people.xml)
 
 which definition file to use ?
 
-=item B<connections_file> (type: devf, default: xmlx/connections/connections.xml)
+=item B<connections_file> (type: modu, default: xmlx/connections/connections.xml)
 
 which connections file to use ?
 
@@ -178,6 +178,7 @@ None.
 	0.15 MV web site automation
 	0.16 MV SEE ALSO section fix
 	0.17 MV move tests to modules
+	0.18 MV teachers project
 
 =head1 SEE ALSO
 
