@@ -12,9 +12,10 @@ use Meta::Tool::Gcc qw();
 use Meta::Utils::Options qw();
 use Meta::Lang::Cpp::Libs qw();
 use Meta::Utils::File::Patho qw();
+use Meta::Development::Module qw();
 
 our($VERSION,@ISA);
-$VERSION="0.26";
+$VERSION="0.27";
 @ISA=qw();
 
 #sub get_path();
@@ -90,8 +91,8 @@ sub get_dom($) {
 
 sub link($$$$$$$$$$$$$$$$) {
 	my($verb,$demo,$proc,$trg0,$trg1,$trg2,$trg3,$src0,$src1,$src2,$src3,$prm0,$prm1,$prm2,$prm3,$path)=@_;
-	
-	my($options)=Meta::Utils::Options->new_deve("data/baseline/cook/ccxx.txt");
+	my($module)=Meta::Development::Module->new_name("data/baseline/cook/ccxx.txt");
+	my($options)=Meta::Utils::Options->new_modu($module);
 	my($einc)=$options->get("base_cook_lang_ccxx_incl");
 	my($elib)=$options->get("base_cook_lang_ccxx_link");
 
@@ -261,7 +262,8 @@ sub compile($) {
 	my(@comps)=split('/',$targ);
 	my($dire)=join('/',$comps[0],$comps[1]);
 #	Meta::Utils::Output::print("dire is [".$dire."]\n");
-	my($options)=Meta::Utils::Options->new_deve("data/baseline/cook/ccxx.txt");
+	my($module)=Meta::Development::Module->new_name("data/baseline/cook/ccxx.txt");
+	my($options)=Meta::Utils::Options->new_modu($module);
 	my($einc)=$options->get("base_cook_lang_ccxx_incl");
 	my($elib)=$options->get("base_cook_lang_ccxx_link");
 #	Meta::Utils::Output::print("ccxx is [".$srcx."]\n");
@@ -472,7 +474,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 
 	MANIFEST: Gcc.pm
 	PROJECT: meta
-	VERSION: 0.26
+	VERSION: 0.27
 
 =head1 SYNOPSIS
 
@@ -606,10 +608,11 @@ None.
 	0.24 MV web site automation
 	0.25 MV SEE ALSO section fix
 	0.26 MV bring movie data
+	0.27 MV teachers project
 
 =head1 SEE ALSO
 
-Meta::Baseline::Arch(3), Meta::Lang::Cpp::Libs(3), Meta::Tool::Gcc(3), Meta::Utils::File::Patho(3), Meta::Utils::Options(3), Meta::Utils::Output(3), Meta::Utils::System(3), Meta::Utils::Unix(3), XML::DOM(3), strict(3)
+Meta::Baseline::Arch(3), Meta::Development::Module(3), Meta::Lang::Cpp::Libs(3), Meta::Tool::Gcc(3), Meta::Utils::File::Patho(3), Meta::Utils::Options(3), Meta::Utils::Output(3), Meta::Utils::System(3), Meta::Utils::Unix(3), XML::DOM(3), strict(3)
 
 =head1 TODO
 
