@@ -7,14 +7,13 @@ use Meta::Utils::File::File qw();
 use Meta::Utils::Env qw();
 use Meta::Utils::Utils qw();
 use Meta::Ds::Ohash qw();
-use Meta::Baseline::Aegis qw();
 
 our($VERSION,@ISA);
-$VERSION="0.34";
+$VERSION="0.35";
 @ISA=qw(Meta::Ds::Ohash);
 
 #sub new_file($$);
-#sub new_deve($$);
+#sub new_modu($$);
 #sub read($$);
 #sub getd($$$);
 #sub getenv($$);
@@ -29,10 +28,9 @@ sub new_file($$) {
 	return($object);
 }
 
-sub new_deve($$) {
-	my($class,$deve)=@_;
-	my($object)=&new_file($class,Meta::Baseline::Aegis::which($deve));
-	return($object);
+sub new_modu($$) {
+	my($class,$modu)=@_;
+	return(&new_file($class,$modu->get_abs_path()));
 }
 
 sub read($$) {
@@ -109,13 +107,13 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 
 	MANIFEST: Options.pm
 	PROJECT: meta
-	VERSION: 0.34
+	VERSION: 0.35
 
 =head1 SYNOPSIS
 
 	package foo;
 	use Meta::Utils::Options qw();
-	my($opti)=Meta::Utils::Options->new_deve();
+	my($opti)=Meta::Utils::Options->new_modu($my_module);
 	$opti->read("my_configuration_file");
 	$obje=$opti->get("my_variable");
 
@@ -126,7 +124,7 @@ This library lets you read and write configuration files.
 =head1 FUNCTIONS
 
 	new_file($$)
-	new_deve($$)
+	new_modu($$)
 	read($$)
 	getd($$$)
 	getenv($$)
@@ -140,9 +138,9 @@ This library lets you read and write configuration files.
 
 This method will give you a new Options object read from a file.
 
-=item B<new_deve($$)>
+=item B<new_modu($$)>
 
-Gives you a new options object according to a development file.
+Gives you a new options object according to a development module.
 
 =item B<read($$)>
 
@@ -215,10 +213,11 @@ None.
 	0.32 MV web site automation
 	0.33 MV SEE ALSO section fix
 	0.34 MV bring movie data
+	0.35 MV teachers project
 
 =head1 SEE ALSO
 
-Meta::Baseline::Aegis(3), Meta::Ds::Ohash(3), Meta::Utils::Env(3), Meta::Utils::File::File(3), Meta::Utils::Utils(3), strict(3)
+Meta::Ds::Ohash(3), Meta::Utils::Env(3), Meta::Utils::File::File(3), Meta::Utils::Utils(3), strict(3)
 
 =head1 TODO
 
